@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/BulletinBoard.c,v 1.1 2004/08/28 19:22:43 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/BulletinBoard.c,v 1.2 2004/09/27 17:44:42 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/BulletinBoard.c,v 1.1 2004/08/28 19:22:43 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/BulletinBoard.c,v 1.2 2004/09/27 17:44:42 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -466,7 +466,10 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     }
     else
     {
+	XmFontList	o = BB_LabelFontList(new_w);
 	BB_LabelFontList(bb) = XmFontListCopy(BB_LabelFontList(new_w));
+	if (o)
+		XmFontListFree(o);
     }
 
     if (!BB_ButtonFontList(bb))
@@ -475,7 +478,10 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     }
     else
     {
+	XmFontList	o = BB_ButtonFontList(new_w);
 	BB_ButtonFontList(bb) = XmFontListCopy(BB_ButtonFontList(new_w));
+	if (o)
+		XmFontListFree(o);
     }
 
     if (!BB_TextFontList(bb))
@@ -484,7 +490,10 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     }
     else
     {
+	XmFontList	o = BB_TextFontList(new_w);
 	BB_TextFontList(bb) = XmFontListCopy(BB_TextFontList(new_w));
+	if (o)
+		XmFontListFree(o);
     }
 
     if (((XmBulletinBoardWidgetClass)XtClass(new_w))->bulletin_board_class.always_install_accelerators)
