@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/FontList.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/FontList.c,v 1.2 2004/09/27 16:54:10 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 2000, 2001, 2002, 2004 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: FontList.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $";
+static const char rcsid[] = "$Id: FontList.c,v 1.2 2004/09/27 16:54:10 dannybackx Exp $";
 
 #include <LTconfig.h>
 #include <string.h>
@@ -45,7 +45,9 @@ XmFontListEntry _XmFontListEntryCreate(void)
 
 	r = (XmFontListEntry)XtMalloc(sizeof(struct __XmRenditionRec));
 	memset(r, 0, sizeof(struct __XmRenditionRec));
-	r->count = 1;
+
+	r->count = 1;		/* This is a usage count, initialise to 1. */
+
 #ifdef DEBUG_POINTERS
 	DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmFontListEntryCreate %p\n", r));
 #endif
@@ -55,16 +57,12 @@ XmFontListEntry _XmFontListEntryCreate(void)
 XmFontList __XmFontListAlloc(int numberOfEntries)
 {
 	XmFontList newFontList;
-#if 0
-#ifdef DEBUG_POINTERS
-	DEBUGOUT(_LtDebug(__FILE__, NULL, "__XmFontListAlloc(%d) ->",
-		numberOfEntries));
-#endif
-#endif
+
 	/* Allocate one more, this entry should have tag NULL */
 	newFontList = (XmFontList)XtMalloc(sizeof(struct __XmRenderTableRec));
 
-	newFontList->count = numberOfEntries;
+	newFontList->count = numberOfEntries;		/* #entries to be provided for */
+
 	newFontList->renditions = (struct __XmRenditionRec **)XtCalloc(
 		numberOfEntries + 1,
 		sizeof(struct __XmRenditionRec *));
@@ -72,10 +70,8 @@ XmFontList __XmFontListAlloc(int numberOfEntries)
 
 	/* This is the one with the NULL tag. */
 	newFontList->renditions[numberOfEntries] = _XmFontListEntryCreate();
-#ifdef DEBUG_POINTERS
 	DEBUGOUT(_LtDebug(__FILE__, NULL, "__XmFontListAlloc(%d) -> %p\n",
 		numberOfEntries, newFontList));
-#endif
 	return newFontList;
 }
 
@@ -91,6 +87,9 @@ __XmFontListDealloc(XmFontList list)
 {
 	int	i;
 
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "__XmFontListDealloc(%p) count %d\n",
+				list, list->count));
+
 	if (list) {
 		if (list->renditions) {
 			for (i=0; i<list->count; i++)
@@ -189,6 +188,9 @@ XmFontListAppendEntry(XmFontList old, XmFontListEntry entry)
 			/* Copy the pointer */
 			newFontList->renditions[i] = old->renditions[i];
 			old->renditions[i]->count++;
+			DEBUGOUT(_LtDebug(__FILE__, NULL,
+				"XmFontListAppendEntry(%p,%p) -> rendition %p %d count ++ %d\n",
+				old, entry, old->renditions[i], i, old->renditions[i]->count));
 		}
 
 		__XmFontListDealloc(old);
@@ -353,6 +355,9 @@ extern XmFontList XmFontListCopy(XmFontList fontlist)
 		/* Additionally allocate the structure here !! */
 		newFontList->renditions[i] = fontlist->renditions[i];
 		fontlist->renditions[i]->count++;
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListCopy(%p) entry %p %d count ++ %d\n",
+					fontlist, i, fontlist->renditions[i],
+					fontlist->renditions[i]->count));
 	}
 #ifdef DEBUG_POINTERS
 	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListCopy(%p) -> %p\n",
@@ -392,7 +397,8 @@ XmFontListEntryFree(XmFontListEntry *pentry)
 	}
 
 	e = *pentry;
-	e->count--;
+	e->count--;		/* Decrement the usage counter */
+
 	if (e->count > 0) {
 #ifdef DEBUG_POINTERS
 		DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryFree(%p) use_count %d\n",
