@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manager.c,v 1.2 2004/09/25 14:49:17 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manager.c,v 1.3 2004/09/28 18:39:08 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manager.c,v 1.2 2004/09/25 14:49:17 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manager.c,v 1.3 2004/09/28 18:39:08 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -1864,9 +1864,13 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 
     for (i = 0; i < MGR_NumKeyboardEntries(w); i++)
     {
+          /* Modified 21-Sep-04 - dwilliss - MicroImages, Inc
+	 Accelerator shouldn't care if CapsLock or NumLock is down. Ideally, the 
+	 accelerator specification should have been able to tell us "only these 
+	 modifiers" or "these modifiers plus any others" */
 	if (/*MGR_KeyboardList(w)[i].eventType == event->type && */
 	    MGR_KeyboardList(w)[i].key == event->xkey.keycode &&
-	    MGR_KeyboardList(w)[i].modifiers == event->xkey.state &&
+	    (MGR_KeyboardList(w)[i].modifiers & event->xkey.state) == MGR_KeyboardList(w)[i].modifiers &&
 	    MGR_KeyboardList(w)[i].component == comp &&
 	    XtIsManaged(comp))
 	{
@@ -2061,8 +2065,20 @@ AddKeyboardEntry(Widget m, Widget w, XmKeyboardData *item)
 
     if (item->needGrab)
     {
+      /* Modified 21-Sep-04 - dwilliss - MicroImages, Inc
+	 Grab for accelerator - accelerator shouldn't care if CapsLock or NumLock
+	 is down, but we have to XtGrabKey with all combinations of them or we only 
+	 get called if they're off. Ideally, the accelerator specification should
+	 have been able to tell us "only these modifiers" or "these modifiers plus
+	 any others" */
 	XtGrabKey(m, item->key, item->modifiers, False,
 		  GrabModeAsync, GrabModeAsync);
+        XtGrabKey(m, item->key, item->modifiers | LockMask, False,
+		  GrabModeAsync, GrabModeAsync);
+	XtGrabKey(m, item->key, item->modifiers | Mod2Mask, False,
+		  GrabModeAsync, GrabModeAsync);
+	XtGrabKey(m, item->key, item->modifiers | Mod2Mask | LockMask, False,
+		  GrabModeAsync, GrabModeAsync);
     }
 }
 
@@ -2090,7 +2106,12 @@ DeleteKeyboardEntry(Widget m, Widget w, Boolean isMnemonic)
 
 	    if (data->needGrab)
 	    {
+	     /* Modified 21-Sep-04 - dwilliss - MicroImages, Inc
+		  To balance change made to AddKeyboardEntry above */
 		XtUngrabKey(m, data->key, data->modifiers);
+		XtUngrabKey(m, data->key, data->modifiers | LockMask);
+		XtUngrabKey(m, data->key, data->modifiers | Mod2Mask);
+		XtUngrabKey(m, data->key, data->modifiers | LockMask | Mod2Mask);
 	    }
 
 	    if (i < MGR_NumKeyboardEntries(m) - 1)
